"""
 rdr_pg_insert_for_robot.py

 @author East Japan Accounting Center Co., Ltd

 (c)2023 The University of Aizu
 This software is released under the New BSD License.
"""
from copy import copy
from logging import getLogger

from pcd_creator import PcdCreator

logger = getLogger(__name__)


class PointCloud2Message:

    @classmethod
    def point_cloud_insert(cls, message, pg_ins, pg_cur) -> bool:
        """

        Parameters
        ----------
        message: dict
        pg_ins: PostgreSQL instance
        pg_cur: PostgreSQL cursor

        Returns
        -------
        rtn: Insert Result

        """

        rtn = False

        doc = copy(message)
        ins = PcdCreator()
        logger.info("PCD file create start")
        run_result, path = ins.run(doc)
        logger.info("PCD file create end")

        pg_ins._tbl_name = "robot_point_cloud"
        INSERT_PCD = "INSERT INTO {} (robot_id, datetime, space, data_path) VALUES (%s, %s, %s, %s)"
        param = (doc["id"], doc["time"], doc["space"], path)
        if pg_ins.insert(pg_cur, INSERT_PCD, param):
            pg_ins._commit()
            rtn = True
            logger.info("DB insert:[{}]".format(pg_ins._tbl_name))
        else:
            pg_ins._rollback()

        return rtn
